@@ -111,7 +111,7 @@ class Client(object):
             'X-Forwarded-For': end_user_ip,
             'X-Forwarded-API-Key': rate_limit_api_key,
             'X-Algolia-Application-Id': self.application_id,
-            'User-Agent': 'Algolia Search for python'
+            'User-Agent': ('Algolia Search for python %s' % VERSION)
         }
 
     @deprecated
@@ -125,9 +125,15 @@ class Client(object):
             'Content-Type': 'application/json; charset=utf-8',
             'X-Algolia-API-Key': self.api_key,
             'X-Algolia-Application-Id': self.application_id,
-            'User-Agent': 'Algolia Search for python'
+            'User-Agent': ('Algolia Search for python %s' % VERSION)
         }
 
+    def set_extra_header(self, key, value):
+        """
+        Allow to set custom header
+        """
+        self.headers[key] = value
+
     @deprecated
     def multipleQueries(self, queries, index_name_key = "indexName"):
         return self.multiple_queries(queries, index_name_key)
@@ -825,7 +831,7 @@ def AlgoliaUtils_request(headers, hosts, method, request, body = None):
     """
     Util function used to send request
     """
-    last_e = None
+    exceptions = {}
     for host in hosts:
         try:
             obj = None
@@ -845,12 +851,9 @@ def AlgoliaUtils_request(headers, hosts, method, request, body = None):
         except AlgoliaException as e:
             raise e
         except Exception as e:
-            last_e = e
+            exceptions[host] = e.message
             pass
-    if last_e is not None:
-        raise last_e
-    else:
-        raise AlgoliaException("Unreachable host")
+    raise AlgoliaException(("%s %s" % ("Unreachable host:", exceptions)))
 
 class JSONEncoderWithDatetimeAndDefaultToString(json.JSONEncoder):
     def default(self, obj):
